@@ -228,6 +228,21 @@ static bool hasCommonPrefix(QStringView lhs, QStringView rhs)
     return lhs.startsWith(rhs, Qt::CaseInsensitive) || rhs.startsWith(lhs, Qt::CaseInsensitive);
 }
 
+[[nodiscard]] static bool isStrictLongPrefix(QStringView lhs, QStringView rhs)
+{
+    // 17 is the maximum field length in RCT2
+    if (lhs.size() < 17 || rhs.size() < 17) {
+        return false;
+    }
+    if (lhs.startsWith(rhs, Qt::CaseInsensitive)) {
+        return lhs.at(rhs.size()).isLetter();
+    }
+    if (rhs.startsWith(lhs, Qt::CaseInsensitive)) {
+        return rhs.at(lhs.size()).isLetter();
+    }
+    return false;
+}
+
 static bool isSameLocationName(const QString &lhs, const QString &rhs, LocationUtil::Accuracy accuracy)
 {
     if (lhs.isEmpty() || rhs.isEmpty()) {
@@ -249,6 +264,11 @@ static bool isSameLocationName(const QString &lhs, const QString &rhs, LocationU
         return true;
     }
 
+    // sufficiently long prefix that we can assume RCT2 field overflow
+    if (isStrictLongPrefix(lhs, rhs)) {
+        return true;
+    }
+
     if (accuracy == LocationUtil::CityLevel) {
         // check for a common prefix
         return hasCommonPrefix(lhsNormalized, rhsNormalized) || hasCommonPrefix(lhsTransliterated, rhsTransliterated);
@@ -261,6 +281,13 @@ bool LocationUtil::isSameLocation(const QVariant &lhs, const QVariant &rhs, Loca
 {
     const auto lhsGeo = geo(lhs);
     const auto rhsGeo = geo(rhs);
+    const auto lhsAddr = address(lhs);
+    const auto rhsAddr = address(rhs);
+
+    const auto lhsIsTransportStop = JsonLd::isA<Airport>(lhs) || JsonLd::isA<TrainStation>(lhs) || JsonLd::isA<BusStation>(lhs);
+    const auto rhsIsTransportStop = JsonLd::isA<Airport>(rhs) || JsonLd::isA<TrainStation>(rhs) || JsonLd::isA<BusStation>(rhs);
+    const auto isNameComparable = lhsIsTransportStop && rhsIsTransportStop;
+
     if (lhsGeo.isValid() && rhsGeo.isValid()) {
         const auto d = distance(lhsGeo, rhsGeo);
         switch (accuracy) {
@@ -279,15 +306,13 @@ bool LocationUtil::isSameLocation(const QVariant &lhs, const QVariant &rhs, Loca
                 if (d < 2000) {
                     return true;
                 }
-                if (d < 50000 && address(lhs).addressLocality().isEmpty() && name(lhs).isEmpty()) {
+                if (d < 50000 && (lhsAddr.addressLocality().isEmpty() || rhsAddr.addressLocality().isEmpty()) && (!isNameComparable || name(lhs).isEmpty() || name(rhs).isEmpty())) {
                     return true;
                 }
                 break;
         }
     }
 
-    const auto lhsAddr = address(lhs);
-    const auto rhsAddr = address(rhs);
     switch (accuracy) {
         case Exact:
         case WalkingDistance:
